@@ -481,7 +481,7 @@
 	     (format p ");~%")))
 	 signatures)
 	(format p "  }~%~%")
-	(format p "  cur_env = s7_outlet(sc, s7_curlet(sc));~%") ; this must exist because we pass load the env ourselves
+	(format p "  cur_env = s7_curlet(sc);~%") ; changed from s7_outlet(s7_curlet) 20-Aug-17
 	
 	;; send out any special initialization code
 	(for-each
@@ -525,10 +525,11 @@
 			(trans (C->s7 type)))
 		   (format p "#ifdef ~A~%" c-name)
 		   (if (eq? trans 's7_make_c_pointer_with_type)
-		       (format p "  s7_define(sc, cur_env, s7_make_symbol(sc, ~S), s7_make_c_pointer(sc, (~A)~A));~%" 
+		       (format p "  s7_define(sc, cur_env, s7_make_symbol(sc, ~S), s7_make_c_pointer_with_type(sc, (~A)~A, s7_make_symbol(sc, \"~S\"), s7_f(sc)));~%" 
 			       scheme-name
 			       (C->s7-cast type)
-			       c-name)
+			       c-name
+			       type)
 		       (format p "  s7_define(sc, cur_env, s7_make_symbol(sc, ~S), ~A(sc, (~A)~A));~%" 
 			       scheme-name
 			       trans
@@ -671,9 +672,9 @@
 	(delete-file o-file-name))
       
       ;; load the object file, clean up
-      (let ((new-env (sublet cur-env 'init_func (string->symbol init-name))))
-	(format *stderr* "loading ~A~%" so-file-name)
-	(load so-file-name new-env)))))
+      (varlet cur-env 'init_func (string->symbol init-name))
+      (format *stderr* "loading ~A~%" so-file-name)
+      (load so-file-name cur-env))))
 
 
 #|
