@@ -1656,7 +1656,7 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
       SG_SIGNAL_CONNECT(STOP_PIX(sp), "button_press_event", stop_sign_press, sp);
 
       {
-	int i;
+	unsigned int i;
 
 	sp->clock_widgets = (GtkWidget **)calloc(sp->nchans, sizeof(GtkWidget *));
 	sp->clock_pix_ax = (graphics_context **)calloc(sp->nchans, sizeof(graphics_context *));
@@ -2104,7 +2104,9 @@ void snd_info_cleanup(snd_info *sp)
 
 void show_controls(snd_info *sp)
 {
+#if (!GTK_CHECK_VERSION(3, 90, 0))
   gtk_widget_show_all(CONTROL_PANEL(sp));
+#endif
   /* control panel is pane 2 of SND_PANE(sp); PANE_BOX is pane 1 */
   /* gtk_paned_set_position(GTK_PANED(sound_pane(ss)), (gint)(widget_height(sound_pane(ss)) * .75)); (glistener) */
 }
