@@ -909,7 +909,7 @@ void widget_mus_long_t_to_text(GtkWidget *w, mus_long_t val)
 {
   char *str;
   str = (char *)calloc(8, sizeof(char));
-  snprintf(str, 8, "%lld", val);
+  snprintf(str, 8, "%" PRId64, val);
   gtk_entry_set_text(GTK_ENTRY(w), str);
   free(str);
 }
@@ -947,7 +947,7 @@ void ensure_scrolled_window_row_visible(widget_t list, int row, int num_rows)
     {
       if (row >= (num_rows - 1))
 	new_value = maximum;
-      else new_value = ((row + 0.5) * ((maximum - minimum) / (float)(num_rows - 1)));
+      else new_value = ((row + 0.5) * ((maximum - minimum) / (double)(num_rows - 1)));
     }
   if (new_value != ADJUSTMENT_VALUE(v))
     ADJUSTMENT_SET_VALUE(v, new_value);
