@@ -55,11 +55,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "3-Aug-17"
+#define SND_DATE "17-Oct-17"
 #ifndef SND_VERSION
-#define SND_VERSION "17.6"
+#define SND_VERSION "17.7"
 #endif
 #define SND_MAJOR_VERSION "17"
-#define SND_MINOR_VERSION "6"
+#define SND_MINOR_VERSION "7"
 
 #endif
