@@ -4,13 +4,13 @@
 
 (if (provided? 'snd)
     (begin
-      (format *stderr* "this won't work in Snd!~%") ; see t705.scm
+      (format *stderr* "this won't work in Snd!~%")
       (exit)))
 
 ;(load "stuff.scm")
 ;(load "r7rs.scm")
 (require mockery.scm)
-
+;(load "s7test-block.so" (sublet (curlet) (cons 'init_func 'block_init)))
 (define max-args 3)
 (define-constant one 1)
 
@@ -41,7 +41,7 @@
 			'((1 2) (3 4)) '((1 (2)) (((3) 4))) "" (list #i(1) "1") '(1 2 . 3) (list (cons 'a 2) (cons 'b 3))
 			#i(1 2) (vector 1 '(3)) (let ((x 3)) (lambda (y) (+ x y))) abs 'a 'b one
 			(lambda args args) (lambda* ((a 3) (b 2)) (+ a b)) (lambda () 3)
-			(sublet () 'a 1) (rootlet)
+			(sublet () 'a 1) ;(rootlet)
 			*load-hook*  *error-hook* (random-state 123)
 			quasiquote macroexpand begin let letrec* if case cond (call-with-exit (lambda (goto) goto))
 			(with-baffle (call/cc (lambda (cc) cc)))
@@ -55,6 +55,11 @@
 			(lambda (dir) 1.0) (float-vector) (make-float-vector '(2 32)) 
 			'((a . 1)) #i(1) '((((A . B) C . D) (E . F) G . H) ((I . J) K . L) (M . N) O . P)
 
+			;(make-block 2) (block 1.0 2.0 3.0) (block) 
+			#u8(0 1 2) (openlet (inlet 'abs (lambda (x) (- x))))
+			(make-iterator (list 1 2 3)) (make-iterator (string #\1)) #<eof> #r2d((.1 .2) (.3 .4))
+			(dilambda (lambda () 1) (lambda (a) a))
+
 			(mock-number 0) (mock-number 1-i) (mock-number 4/3) (mock-number 2.0)
 			(mock-string #\h #\o #\h #\o)
 			(mock-pair '(2 3 4))
@@ -83,9 +88,10 @@
 	   (lambda () 
 	     ;(format *stderr* "args: ~A~%" args)
 	     (apply func args))
-	   (lambda any
+	   (lambda (type info)
 	     (if (and (positive? args-now)
-		      (memq (car any) '(wrong-type-arg wrong-number-of-args syntax-error)))
+		      (memq type '(wrong-type-arg wrong-number-of-args out-of-range syntax-error io-error
+				   division-by-zero format-error missing-method error invalid-escape-function)))
 		 (quit)))))
      
      (let ((c-args (vector-ref auto-arglists args-now)))
@@ -118,12 +124,14 @@
 		(catch #t
 		  (lambda ()
 		    (apply func c-args))
-		  (lambda any 
-		    (if (and (memq (car any) '(wrong-type-arg wrong-number-of-args syntax-error))
-			     (pair? (cdadr any))
-			     (pair? (cddadr any))
-			     (integer? (caddr (cadr any))) ; if just 1 arg, arg num can be omitted
-			     (< (caddr (cadr any)) low))
+		  (lambda (type info)
+		    (if (or (memq type '(wrong-number-of-args out-of-range syntax-error io-error
+					 division-by-zero format-error error missing-method invalid-escape-function))
+			    (and (eq? type 'wrong-type-arg)
+				 (pair? (cdr info))
+				 (pair? (cddr info))
+				 (integer? (caddr info)) ; if just 1 arg, arg num can be omitted
+				 (< (caddr info) low)))
 			(quit))))
 		 
 		(if checker ; map-values -> function here
@@ -144,7 +152,7 @@
 		  auto-constants))))))))
 
 (define safe-fill!
-  (let ((signature '(#t sequence? #t)))
+  (let ((+signature+ '(#t sequence? #t)))
     (lambda (obj arg)
       (if (not (let? obj))
 	  (fill! obj arg)))))
@@ -168,7 +176,7 @@
 		  symbol-table load local-symbol?
 		  global-environment current-environment make-procedure-with-setter procedure-with-setter? make-rectangular
 		  
-		  copy fill! hash-table-set! vector-set! let-set! list-values apply-values
+		  copy fill! hash-table-set! vector-set! let-set! list-values apply-values immutable!
 		  
 		  mock-number mock-pair mock-string mock-char mock-vector mock-hash-table*
 		  mock-symbol mock-port mock-hash-table m mock->string make-local-method
@@ -190,7 +198,7 @@
 		  (strname (symbol->string sym)))
 	      (if (not (memv (strname 0) '(#\{ #\[ #\()))
 		  (begin
-		    ;(if (not (procedure-signature f)) (format *stderr* "~A~%" sym))
+		    ;(if (not (signature f)) (format *stderr* "~A~%" sym))
 		    (if (< top bottom)
 			(format *stderr* ";~A (bottom: ~A, top: ~A)...~%" sym bottom top))
 					;(format *stderr* ";~A...~%" sym)
@@ -199,7 +207,7 @@
 			(let ((sig (cond ((eq? sym 'append)
 					  (let ((lst (list 'list?)))
 					    (set-cdr! lst lst)))
-					 ((procedure-signature f) => copy))))
+					 ((signature f) => copy))))
 			  (map-values sig)
 			  (autotest f () 0 top (if (pair? sig) (cdr sig) ())))))))))))
 
